Package: canpumf
Type: Package
Title: Parse StatCan PUMF Files
Version: 0.5.2
Authors@R: c(
    person("Jens", "von Bergmann", email = "jens@mountainmath.ca", role = c("aut", "cre"))
    )
Description: Facilitate working with Statistics Canada (StatCan) Public Use
    Microdata Files (PUMF). Enables downloading of available PUMF data,
    parsing of metadata from command files or other sources to infer the layout
    structure, variable labels and value labels as well as missing data values,
    and returns a connection to a 'DuckDB' database with the labelled data.
    Data and documentation come from Statistics Canada's Public Use Microdata
    Files <https://www.statcan.gc.ca/en/microdata/pumf>, distributed under the
    Statistics Canada Open Licence
    <https://www.statcan.gc.ca/en/terms-conditions/open-licence>.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.2)
Imports: dplyr (>= 1.1.0), readr, stringr, rlang, utils, tibble, rvest,
        httr, purrr, DBI, duckdb (>= 1.5.2), duckplyr (>= 1.2.1),
        dbplyr, haven (>= 2.5.0), zip
Suggests: rmarkdown, knitr, scales, ggplot2, testthat (>= 3.0.0),
        withr, microbenchmark, DiagrammeR, DiagrammeRsvg, rsvg,
        pdftools, tidyr
URL: https://github.com/mountainMath/canpumf,
        https://mountainmath.github.io/canpumf/
BugReports: https://github.com/mountainMath/canpumf/issues
VignetteBuilder: knitr
Language: en-CA
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-27 16:14:21 UTC; jens
Author: Jens von Bergmann [aut, cre]
Maintainer: Jens von Bergmann <jens@mountainmath.ca>
Repository: CRAN
Date/Publication: 2026-07-03 12:10:09 UTC
Built: R 4.6.0; ; 2026-07-03 16:16:13 UTC; unix
