# Generated by roxygen2: do not edit by hand

S3method(print,pumf_registry_entry)
export(add_bootstrap_weights)
export(add_lfs_GENDER_SEX)
export(add_lfs_SURVDATE)
export(bsw_info)
export(close_pumf)
export(get_pumf)
export(get_pumf_connection)
export(label_pumf_columns)
export(list_available_lfs_pumf_versions)
export(list_canpumf_collection)
export(list_pumf_cache)
export(list_pumf_registry)
export(list_statcan_pumf_catalogue)
export(open_pumf_documentation)
export(pumf_metadata)
export(pumf_module)
export(pumf_registry)
export(pumf_registry_entry)
export(pumf_var_labels)
export(remove_bootstrap_weights)
export(remove_pumf_cache)
import(dplyr)
import(duckplyr)
import(readr)
import(stringr)
importFrom(dbplyr,sql_render)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,head)
